==> rsuite-4.0.1.tgz: package/src/Radio/Radio.tsx <==
import * as React from 'react';
import PropTypes from 'prop-types';
import classNames from 'classnames';
import _ from 'lodash';
import setDisplayName from 'recompose/setDisplayName';

import { prefix, getUnhandledProps, partitionHTMLProps, defaultProps } from '../utils';
import { RadioProps } from './Radio.d';

interface RadioState {
  checked?: boolean;
}

class Radio extends React.Component<RadioProps, RadioState> {
  static propTypes = {
    id: PropTypes.string,
    name: PropTypes.string,
    inline: PropTypes.bool,
    title: PropTypes.string,
    disabled: PropTypes.bool,
    checked: PropTypes.bool,
    defaultChecked: PropTypes.bool,
    inputRef: PropTypes.func,
    children: PropTypes.node,
    className: PropTypes.string,
    classPrefix: PropTypes.string,
    value: PropTypes.any,
    onChange: PropTypes.func,
    onClick: PropTypes.func,
    tabIndex: PropTypes.number
  };
  static defaultProps = {
    tabIndex: 0
  };

  constructor(props) {
    super(props);
    this.state = {
      checked: props.defaultChecked
    };
  }

  isChecked() {
    const { checked } = this.props;
    return _.isUndefined(checked) ? this.state.checked : checked;
  }

  updateCheckedState(checked: boolean, callback?: () => void) {
    this.setState({ checked }, callback);
  }

  handleChange = (event: React.ChangeEvent<HTMLInputElement>) => {
    const { value, disabled, onChange } = this.props;
    const checked = true;
    if (disabled) {
      return;
    }

    this.setState({ checked }, () => {
      onChange && onChange(value, checked, event);
    });
  };
  render() {
    const {
      inline,
      title,
      name,
      className,
      children,
      disabled,
      checked,
      defaultChecked,
      classPrefix,
      tabIndex,
      inputRef,
      onClick,
      ...props
    } = this.props;

    const nextChecked = this.isChecked();
    const addPrefix = prefix(classPrefix);
    const classes = classNames(classPrefix, className, {
      [addPrefix('inline')]: inline,
      [addPrefix('disabled')]: disabled,
      [addPrefix('checked')]: nextChecked
    });

    const unhandled = getUnhandledProps(Radio, props);
    const [htmlInputProps, rest] = partitionHTMLProps(unhandled);

    const input = (
      <span className={addPrefix('wrapper')} aria-disabled={disabled}>
        <input
          {...htmlInputProps}
          type="radio"
          checked={checked}
          defaultChecked={defaultChecked}
          ref={inputRef}
          name={name}
          tabIndex={tabIndex}
          disabled={disabled}
          onChange={this.handleChange}
          onClick={event => event.stopPropagation()}
        />
        <span className={addPrefix('inner')} aria-hidden={true} role="presentation" />
      </span>
    );

    return (
      <div {...rest} onClick={onClick} className={classes}>
        <div className={addPrefix('checker')}>
          <label title={title}>
            {input}
            {children}
          </label>
        </div>
      </div>
    );
  }
}

const EnhancedRadio = defaultProps<RadioProps>({
  classPrefix: 'radio'
})(Radio);

export default setDisplayName('Radio')(EnhancedRadio);

==> rsuite-4.0.5.tgz: package/src/Radio/Radio.tsx <==
import * as React from 'react';
import PropTypes from 'prop-types';
import classNames from 'classnames';
import _ from 'lodash';
import setDisplayName from 'recompose/setDisplayName';
import { RadioContext, ContextProps } from '../RadioGroup/RadioGroup';

import { prefix, getUnhandledProps, partitionHTMLProps, defaultProps } from '../utils';
import { RadioProps } from './Radio.d';

interface RadioState {
  checked?: boolean;
}

class Radio extends React.Component<RadioProps, RadioState> {
  static contextType = RadioContext;
  static propTypes = {
    id: PropTypes.string,
    name: PropTypes.string,
    inline: PropTypes.bool,
    title: PropTypes.string,
    disabled: PropTypes.bool,
    checked: PropTypes.bool,
    defaultChecked: PropTypes.bool,
    inputRef: PropTypes.func,
    children: PropTypes.node,
    className: PropTypes.string,
    classPrefix: PropTypes.string,
    value: PropTypes.any,
    onChange: PropTypes.func,
    onClick: PropTypes.func,
    tabIndex: PropTypes.number
  };
  static defaultProps = {
    tabIndex: 0
  };
  context: ContextProps = {};

  constructor(props) {
    super(props);
    this.state = {
      checked: props.defaultChecked
    };
  }
  getCheckedByValue() {
    const { value } = this.props;
    if (!_.isUndefined(this.context.value)) {
      return this.context.value === value;
    }
    return this.props.checked;
  }

  updateCheckedState(checked: boolean, callback?: () => void) {
    this.setState({ checked }, callback);
  }

  handleChange = (event: React.ChangeEvent<HTMLInputElement>) => {
    const { value, disabled, onChange } = this.props;
    const { onChange: onContextChange } = this.context;
    const checked = true;
    if (disabled) {
      return;
    }

    this.setState({ checked }, () => {
      onChange && onChange(value, checked, event);
      onContextChange && onContextChange(value, checked, event);
    });
  };
  render() {
    const {
      title,
      className,
      children,
      disabled,
      defaultChecked,
      classPrefix,
      tabIndex,
      inputRef,
      onClick,
      ...props
    } = this.props;

    const { inline = this.props.inline, name = this.props.name } = this.context;
    const checked = this.getCheckedByValue();
    const addPrefix = prefix(classPrefix);
    const classes = classNames(classPrefix, className, {
      [addPrefix('inline')]: inline,
      [addPrefix('disabled')]: disabled,
      [addPrefix('checked')]: _.isUndefined(checked) ? this.state.checked : checked
    });

    const unhandled = getUnhandledProps(Radio, props);
    const [htmlInputProps, rest] = partitionHTMLProps(unhandled);

    const input = (
      <span className={addPrefix('wrapper')} aria-disabled={disabled}>
        <input
          {...htmlInputProps}
          type="radio"
          checked={checked}
          defaultChecked={defaultChecked}
          ref={inputRef}
          name={name}
          tabIndex={tabIndex}
          disabled={disabled}
          onChange={this.handleChange}
          onClick={event => event.stopPropagation()}
        />
        <span className={addPrefix('inner')} aria-hidden={true} role="presentation" />
      </span>
    );

    return (
      <div {...rest} onClick={onClick} className={classes}>
        <div className={addPrefix('checker')}>
          <label title={title}>
            {input}
            {children}
          </label>
        </div>
      </div>
    );
  }
}

const EnhancedRadio = defaultProps<RadioProps>({
  classPrefix: 'radio'
})(Radio);

export default setDisplayName('Radio')(EnhancedRadio);
